@@ -1,10 +1,10 @@
 from ldap.filter import escape_filter_chars
 
 from .converters import (
+    BinaryConverter,
+    BoolConverter,
     Converter,
     GeneralTimeConverter,
-    BoolConverter,
-    BinaryConverter,
 )
 
 
@@ -68,4 +68,16 @@ class GroupModel(Model):
     primary_key = "cn"
     filters = "(objectClass=fasGroup)"
     sub_dn = "cn=groups,cn=accounts"
-    fields = {"groupname": Converter("cn")}
+    fields = {
+        "groupname": Converter("cn"),
+        "description": Converter("description"),
+    }
+
+
+class AgreementModel(Model):
+    primary_key = "cn"
+    filters = "(&(objectClass=fasAgreement)(ipaEnabledFlag=TRUE))"
+    sub_dn = "cn=fasagreements"
+    fields = {
+        "name": Converter("cn"),
+    }
